@@ -1,6 +1,6 @@
 package Map::Tube::Barcelona::Line::L4;
 
-$Map::Tube::Barcelona::Line::L4::VERSION   = '0.77';
+$Map::Tube::Barcelona::Line::L4::VERSION   = '0.78';
 $Map::Tube::Barcelona::Line::L4::AUTHORITY = 'cpan:MANWAR';
 
 use 5.006;
@@ -12,7 +12,7 @@ Map::Tube::Barcelona::Line::L4 - Barcelona Metro Map: L4 Line.
 
 =head1 VERSION
 
-Version 0.77
+Version 0.78
 
 =encoding utf8
 
@@ -90,7 +90,7 @@ map generated by plugin L<Map::Tube::Plugin::Graph>.
 
 =head1 AUTHOR
 
-Mohammad S Anwar, C<< <mohammad.anwar at yahoo.com> >>
+Mohammad Sajid Anwar, C<< <mohammad.anwar at yahoo.com> >>
 
 =head1 REPOSITORY
 
@@ -98,43 +98,37 @@ L<https://github.com/manwar/Map-Tube-Barcelona>
 
 =head1 BUGS
 
-Please report any bugs/feature requests to C<bug-map-tube-barcelona at rt.cpan.org>,
-or through the web interface at L<http://rt.cpan.org/NoAuth/ReportBug.html?Queue=Map-Tube-Barcelona>.
-I will be notified, and then you'll automatically be notified of progress on your
+Please report any bugs or feature requests through the web interface at L<https://github.com/manwar/Map-Tube-Barcelona/issues>.
+I will  be notified and then you'll automatically be notified of progress on your
 bug as I make changes.
 
 =head1 SUPPORT
 
 You can find documentation for this module with the perldoc command.
 
-    perldoc Map::Tube::Barcelona::Line::L4
+    perldoc Map::Tube::Barcelona
 
 You can also look for information at:
 
 =over 4
 
-=item * RT: CPAN's request tracker (report bugs here)
+=item * BUG Report
 
-L<http://rt.cpan.org/NoAuth/Bugs.html?Dist=Map-Tube-Barcelona>
-
-=item * AnnoCPAN: Annotated CPAN documentation
-
-L<http://annocpan.org/dist/Map-Tube-Barcelona>
+L<https://github.com/manwar/Map-Tube-Barcelona/issues>
 
 =item * CPAN Ratings
 
 L<http://cpanratings.perl.org/d/Map-Tube-Barcelona>
 
-=item * Search CPAN
+=item * Search MetaCPAN
 
-L<http://search.cpan.org/dist/Map-Tube-Barcelona/>
+L<https://metacpan.org/dist/Map-Tube-Barcelona/>
 
 =back
 
 =head1 LICENSE AND COPYRIGHT
 
-Copyright (C) 2014 - 2019 Mohammad S Anwar.
-
+Copyright (C) 2014 - 2025 Mohammad Sajid Anwar.
 This program  is  free software; you can redistribute it and / or modify it under
 the  terms  of the the Artistic  License (2.0). You may obtain a copy of the full
 license at:
